# Molecule Info H5 Helpers

This repository contains a set of helper functions for reading, subsampling and in future versions visualizing the data in the molecule info h5 files as generated by cellranger.

## Installation

```bash
pip install molecule_info
```

## Usage

```python
import molecule_info as mi

# read
m = mi.MoleculeInfo(path)

# subsample
m.sample_reads(1000, seed=42)

# convert to anndata
adata = m.to_adata()
```
